@@ -1,6 +1,6 @@
 var interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard =
 [
-    [ "XComponent", "interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
+    [ "com::sun::star::lang::XComponent", "interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
     [ "XClipboardEx", "interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html#aac5abb811a50f530ac5b0e9bbefd1a46", null ],
     [ "XClipboardNotifier", "interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html#a82979f0c77f230769987ff41d7293b05", null ],
     [ "XFlushableClipboard", "interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html#a90430db41324cfea5385fd248dd3b9b2", null ]
