@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer =
 [
-    [ "XTimeStamped", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html#a15b5f0e66a2053c0dbb8dcad134e1de9", null ],
+    [ "com::sun::star::util::XTimeStamped", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html#a15b5f0e66a2053c0dbb8dcad134e1de9", null ],
     [ "XCompositeLayer", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html#a8580fb472889df57ac465f26c36ca1f6", null ],
     [ "XLayer", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html#ad87fdf37df6052b2fb1314d441fed97a", null ],
     [ "URL", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html#af82bacfe5b6faf0534ae06a9540cb886", null ]
