@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber =
 [
-    [ "DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
+    [ "com::sun::star::text::DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
     [ "DataBaseName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ae885c1a651d501e99aeffdf65fb8b625", null ],
     [ "DataBaseResource", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#aceebc5c63663ba4a0418a24a2f0a0aaf", null ],
     [ "DataBaseURL", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#a125ebe53f61fca10ac425d4d2ad1945e", null ],
