@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor =
 [
-    [ "TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
+    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
     [ "Author", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor.html#a13cf46aff4dea87a8f5285a09efece69", null ],
     [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
     [ "IsFixed", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1ChangeAuthor.html#a57c3add6784f715a9bed21c3318f41ba", null ]
